<?php

namespace Litecms\LeadershipBonus\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\LeadershipBonus\Models\LeadershipBonus;

class LeadershipBonusPolicy
{

    /**
     * Determine if the given user can view the leadership_bonus.
     *
     * @param UserPolicy $user
     * @param LeadershipBonus $leadership_bonus
     *
     * @return bool
     */
    public function view(UserPolicy $user, LeadershipBonus $leadership_bonus)
    {
        if ($user->canDo('leadership_bonus.leadership_bonus.view') && $user->isAdmin()) {
            return true;
        }

        return $leadership_bonus->user_id == user_id() && $leadership_bonus->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leadership_bonus.
     *
     * @param UserPolicy $user
     * @param LeadershipBonus $leadership_bonus
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('leadership_bonus.leadership_bonus.create');
    }

    /**
     * Determine if the given user can update the given leadership_bonus.
     *
     * @param UserPolicy $user
     * @param LeadershipBonus $leadership_bonus
     *
     * @return bool
     */
    public function update(UserPolicy $user, LeadershipBonus $leadership_bonus)
    {
        if ($user->canDo('leadership_bonus.leadership_bonus.edit') && $user->isAdmin()) {
            return true;
        }

        return $leadership_bonus->user_id == user_id() && $leadership_bonus->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leadership_bonus.
     *
     * @param UserPolicy $user
     * @param LeadershipBonus $leadership_bonus
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LeadershipBonus $leadership_bonus)
    {
        return $leadership_bonus->user_id == user_id() && $leadership_bonus->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leadership_bonus.
     *
     * @param UserPolicy $user
     * @param LeadershipBonus $leadership_bonus
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LeadershipBonus $leadership_bonus)
    {
        if ($user->canDo('leadership_bonus.leadership_bonus.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leadership_bonus.
     *
     * @param UserPolicy $user
     * @param LeadershipBonus $leadership_bonus
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LeadershipBonus $leadership_bonus)
    {
        if ($user->canDo('leadership_bonus.leadership_bonus.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
